/* generated using openapi-typescript-codegen -- do no edit */
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { BucketIn } from '../models/BucketIn';
import type { BucketOut } from '../models/BucketOut';
import type { BucketType } from '../models/BucketType';
import type { S3ObjectMetaInformation } from '../models/S3ObjectMetaInformation';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class BucketService {

    /**
     * List buckets of user
     * List all the buckets in the system or of the desired user where the user has READ permissions for.
     *
     * Permission "bucket:read" required.
     * @param user UID of the user for whom to fetch the buckets for. Permission 'bucket:read_any' required if current user is not the target.
     * @param bucketType Type of the bucket to get. Ignored when `user` parameter not set
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketListBuckets(
        user?: (string | null),
        bucketType?: BucketType,
    ): CancelablePromise<Array<BucketOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets',
            query: {
                'user': user,
                'bucket_type': bucketType,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Create a bucket for the current user
     * Create a bucket for the current user.
     *
     * The name of the bucket has some constraints.
     * For more information see the
     * [Ceph documentation](https://docs.ceph.com/en/quincy/radosgw/s3/bucketops/#constraints)
     *
     * Permission "bucket:create" required.
     * @param requestBody
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketCreateBucket(
        requestBody: BucketIn,
    ): CancelablePromise<BucketOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/buckets',
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a bucket by its name
     * Get a bucket by its name if the current user has READ permissions for the bucket.
     *
     * Permission "bucket:read" required if the current user is the owner of the bucket,
     * otherwise "bucket:read_any" required.
     * @param bucketName Name of bucket
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketGetBucket(
        bucketName: string,
    ): CancelablePromise<BucketOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}',
            path: {
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Delete a bucket
     * Delete a bucket by its name. Only the owner of the bucket can delete the bucket.
     *
     * Permission "bucket:delete" required if the current user is the owner of the bucket,
     * otherwise "bucket:delete_any" required.
     * @param bucketName Name of bucket
     * @param forceDelete Delete even non-empty bucket
     * @returns void
     * @throws ApiError
     */
    public static bucketDeleteBucket(
        bucketName: string,
        forceDelete: boolean = false,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/buckets/{bucket_name}',
            path: {
                'bucket_name': bucketName,
            },
            query: {
                'force_delete': forceDelete,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * @deprecated
     * Get the metadata of the objects in the bucket
     * Get the metadata of the objects in the bucket.
     *
     * If the user has permissions for the bucket and uses the `file_prefix` parameter, it will be concatenated with the
     * allowed prefix from the permission.
     *
     * Permission "bucket:read" required if the current user has access to the bucket,
     * otherwise "bucket:read_any" required.
     * @param bucketName Name of bucket
     * @param filePrefix Get only objects with the specified prefix.
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObjects(
        bucketName: string,
        filePrefix?: (string | null),
    ): CancelablePromise<Array<S3ObjectMetaInformation>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects',
            path: {
                'bucket_name': bucketName,
            },
            query: {
                'file_prefix': filePrefix,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * @deprecated
     * Get the metadata about a specific object
     * Get the metadata of a specific object in a bucket.
     *
     * Permission "bucket:read" required if the current user has access to the bucket,
     * otherwise "bucket:read_any" required.
     * @param objectPath
     * @param bucketName Name of bucket
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObject(
        objectPath: string,
        bucketName: string,
    ): CancelablePromise<S3ObjectMetaInformation> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects/{object_path}',
            path: {
                'object_path': objectPath,
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
