import { createRouter, createWebHistory } from "vue-router";
import DashboardView from "../views/DashboardView.vue";
import LoginView from "../views/LoginView.vue";

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/dashboard",
      name: "dashboard",
      component: DashboardView,
      children: [
        {
          path: "object-storage/buckets",
          name: "buckets",
          component: () => import("../views/object-storage/BucketsView.vue"),
          props: (route) => ({
            bucketName: route.params.bucketName ?? undefined,
          }),
          children: [
            {
              path: ":bucketName/:subFolders*",
              name: "bucket",
              component: () => import("../views/object-storage/BucketView.vue"),
              props: true,
            },
          ],
        },
        {
          path: "object-storage/s3-keys",
          name: "s3_keys",
          component: () => import("../views/object-storage/S3KeysView.vue"),
        },
        {
          path: "workflow-executions",
          name: "workflow-executions",
          component: () =>
            import("../views/workflows/ListWorkflowExecutionsView.vue"),
        },
        {
          path: "workflows",
          name: "workflows",
          component: () => import("../views/workflows/ListWorkflowsView.vue"),
        },
        {
          path: "developer/workflows",
          name: "workflows-developer",
          component: () => import("../views/workflows/MyWorkflowsView.vue"),
          meta: {
            requiresDeveloperRole: true,
          },
        },
        {
          path: "reviewer/workflows",
          name: "workflows-reviewer",
          component: () => import("../views/workflows/ReviewWorkflowsView.vue"),
          meta: {
            requiresReviewerRole: true,
          },
        },
        {
          path: "workflows/arbitrary",
          name: "arbitrary-workflow",
          component: () =>
            import("../views/workflows/ArbitraryWorkflowView.vue"),
          meta: {
            requiresDeveloperRole: true,
          },
          props: (route) => ({
            wid: route.query.wid,
          }),
        },
        {
          path: "workflows/:workflowId",
          name: "workflow",
          component: () => import("../views/workflows/WorkflowView.vue"),
          props: (route) => ({
            versionId: route.params.versionId ?? undefined,
            workflowId: route.params.workflowId,
            workflowModeId: route.query.workflowModeId ?? undefined,
            developerView: route.query.developerView == "true" ?? false,
          }),
          children: [
            {
              path: "version/:versionId",
              name: "workflow-version",
              component: () =>
                import("../views/workflows/WorkflowVersionView.vue"),
              props: (route) => ({
                versionId: route.params.versionId,
                workflowId: route.params.workflowId,
                activeTab: route.query.tab ?? "description",
                workflowModeId: route.query.workflowModeId ?? undefined,
              }),
            },
            {
              path: "version/:versionId/start",
              name: "workflow-start",
              component: () =>
                import("../views/workflows/StartWorkflowView.vue"),
              props: (route) => ({
                versionId: route.params.versionId,
                workflowId: route.params.workflowId,
                workflowModeId: route.query.workflowModeId ?? undefined,
              }),
            },
          ],
        },
      ],
    },
    {
      path: "/login",
      name: "login",
      component: LoginView,
    },
    {
      path: "/",
      redirect: {
        name: "buckets",
      },
    },
    {
      path: "/:pathMatch(.*)",
      component: () => import("../views/NotFoundView.vue"),
    },
  ],
});
export default router;
